==> aliyun-sdk-oss-2.0.2-sources.jar: com/aliyun/oss/model/ObjectListing.java <==
/**
 * Copyright (C) Alibaba Cloud Computing, 2012
 * All rights reserved.
 * 
 * 版权所有 （C）阿里巴巴云计算，2012
 */

package com.aliyun.oss.model;

import java.util.ArrayList;
import java.util.List;

public class ObjectListing {
    
    /** A list of summary information describing the objects stored in the bucket */
    private List<OSSObjectSummary> objectSummaries = new ArrayList<OSSObjectSummary>();

    private List<String> commonPrefixes = new ArrayList<String>();
    
    private String bucketName;

    private String nextMarker;
    
    private boolean isTruncated;
    
    private String prefix;
    
    private String marker;
    
    private int maxKeys;
    
    private String delimiter;

    public List<OSSObjectSummary> getObjectSummaries() {
        return objectSummaries;
    }

    public List<String> getCommonPrefixes() {
        return commonPrefixes;
    }

    public void setCommonPrefixes(List<String> commonPrefixes) {
        this.commonPrefixes = commonPrefixes;
    }

    public String getNextMarker() {
        return nextMarker;
    }

    public void setNextMarker(String nextMarker) {
        this.nextMarker = nextMarker;
    }

    public String getBucketName() {
        return bucketName;
    }

    public void setBucketName(String bucketName) {
        this.bucketName = bucketName;
    }

    public String getPrefix() {
        return prefix;
    }

    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }

    public String getMarker() {
        return marker;
    }

    public void setMarker(String marker) {
        this.marker = marker;
    }

    public int getMaxKeys() {
        return maxKeys;
    }

    public void setMaxKeys(int maxKeys) {
        this.maxKeys = maxKeys;
    }

    public String getDelimiter() {
        return delimiter;
    }

    public void setDelimiter(String delimiter) {
        this.delimiter = delimiter;
    }

    public boolean isTruncated() {
        return isTruncated;
    }

    public void setTruncated(boolean isTruncated) {
        this.isTruncated = isTruncated;
    }

}

==> aliyun-sdk-oss-2.0.3-sources.jar: com/aliyun/oss/model/ObjectListing.java <==
/**
 * Copyright (C) Alibaba Cloud Computing, 2012
 * All rights reserved.
 * 
 * 版权所有 （C）阿里巴巴云计算，2012
 */

package com.aliyun.oss.model;

import java.util.ArrayList;
import java.util.List;

public class ObjectListing {
    
    /** A list of summary information describing the objects stored in the bucket */
    private List<OSSObjectSummary> objectSummaries = new ArrayList<OSSObjectSummary>();

    private List<String> commonPrefixes = new ArrayList<String>();
    
    private String bucketName;

    private String nextMarker;
    
    private boolean isTruncated;
    
    private String prefix;
    
    private String marker;
    
    private int maxKeys;
    
    private String delimiter;

    public List<OSSObjectSummary> getObjectSummaries() {
        return objectSummaries;
    }
    
    public void addObjectSummary(OSSObjectSummary objectSummary) {
    	this.objectSummaries.add(objectSummary);
    }
    
    public void setObjectSummaries(List<OSSObjectSummary> objectSummaries) {
        this.objectSummaries.clear();
        if (objectSummaries != null && !objectSummaries.isEmpty()) {
        	this.objectSummaries.addAll(objectSummaries);
        }
    }
    
    public void clearObjectSummaries() {
    	this.objectSummaries.clear();
    }

    public List<String> getCommonPrefixes() {
        return commonPrefixes;
    }
    
    public void addCommonPrefix(String commonPrefix) {
    	this.commonPrefixes.add(commonPrefix);
    }

    public void setCommonPrefixes(List<String> commonPrefixes) {
        this.commonPrefixes.clear();
        if (commonPrefixes != null && !commonPrefixes.isEmpty()) {
        	this.commonPrefixes.addAll(commonPrefixes);
        }
    }
    
    public void clearCommonPrefixes() {
    	this.commonPrefixes.clear();
    }

    public String getNextMarker() {
        return nextMarker;
    }

    public void setNextMarker(String nextMarker) {
        this.nextMarker = nextMarker;
    }

    public String getBucketName() {
        return bucketName;
    }

    public void setBucketName(String bucketName) {
        this.bucketName = bucketName;
    }

    public String getPrefix() {
        return prefix;
    }

    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }

    public String getMarker() {
        return marker;
    }

    public void setMarker(String marker) {
        this.marker = marker;
    }

    public int getMaxKeys() {
        return maxKeys;
    }

    public void setMaxKeys(int maxKeys) {
        this.maxKeys = maxKeys;
    }

    public String getDelimiter() {
        return delimiter;
    }

    public void setDelimiter(String delimiter) {
        this.delimiter = delimiter;
    }

    public boolean isTruncated() {
        return isTruncated;
    }

    public void setTruncated(boolean isTruncated) {
        this.isTruncated = isTruncated;
    }

}
